@@ -1,20 +1,8 @@
 """
-Copyright 2020 The OneFlow Authors. All rights reserved.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
 """
 import os
 import warnings
+import tarfile
 import collections
 
 from xml.etree.ElementTree import Element as ET_Element
@@ -28,6 +16,7 @@ from typing import Any, Callable, Dict, Optional, Tuple, List
 
 from .utils import download_and_extract_archive, verify_str_arg
 from .vision import VisionDataset
+from .utils import download_url, check_integrity
 
 
 DATASET_YEAR_DICT = {
@@ -254,3 +243,9 @@ class VOCDetection(_VOCBase):
             if not children:
                 voc_dict[node.tag] = text
         return voc_dict
+
+
+def download_extract(url, root, filename, md5):
+    download_url(url, root, filename, md5)
+    with tarfile.open(os.path.join(root, filename), "r") as tar:
+        tar.extractall(path=root)
