@@ -39,11 +39,11 @@ def inception_v3(pretrained: bool = False, progress: bool = True, **kwargs: Any)
 
     Args:
         pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
-        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+        progress (bool): If True, displays a progress bar of the download to stderr. Default: ``True``
         aux_logits (bool): If True, add an auxiliary branch that can improve training.
-            Default: *True*
+            Default: ``True``
         transform_input (bool): If True, preprocesses the input according to the method with which it
-            was trained on ImageNet. Default: *False*
+            was trained on ImageNet. Default: ``False``
 
     For example:
 
