@@ -1,3 +1,6 @@
+"""
+Modified from https://github.com/pytorch/vision/blob/main/torchvision/models/mobilenet.py
+"""
 from .mobilenet_v2 import MobileNetV2, mobilenet_v2, __all__ as mv2_all
 from .mobilenet_v3 import (
     MobileNetV3,
