@@ -1,8 +1,13 @@
+"""
+Modified from https://github.com/rwightman/pytorch-image-models/blob/master/timm/models/registry.py
+"""
 import sys
 import re
 import fnmatch
 from collections import defaultdict
 from copy import deepcopy
+from tabulate import tabulate
+
 import oneflow as flow
 
 
@@ -35,21 +40,21 @@ class ModelCreator(object):
 
     @staticmethod
     def create_model(
-        model_name: str, pretrained: bool = False, checkpoint: bool = None
+        model_name: str, pretrained: bool = False, checkpoint: str = None, **kwargs
     ):
         if model_name in ModelCreator._model_entrypoints:
             create_fn = ModelCreator._model_entrypoints[model_name]
         else:
             raise RuntimeError("Unknown model (%s)" % model_name)
-        model = create_fn(pretrained=pretrained)
+        model = create_fn(pretrained=pretrained, **kwargs)
 
-        if checkpoint:
+        if checkpoint is not None:
             state_dict = flow.load(checkpoint)
             model.load_state_dict(state_dict)
         return model
 
     @staticmethod
-    def model_table(filter="", pretrained=False):
+    def model_table(filter="", pretrained=False, **kwargs):
         all_models = ModelCreator._model_entrypoints.keys()
         if filter:
             models = []
@@ -71,18 +76,11 @@ class ModelCreator(object):
             for model in sorted_model:
                 show_dict[model] = ModelCreator._model_list[model]
 
-        # ModelCreator._model_list
-
-        from rich.table import Table
-        from rich import print
-
-        table = Table(title="Models")
-        table.add_column("Name", justify="left", no_wrap=True)
-        table.add_column("Pretrained", justify="left", no_wrap=True)
-
-        [
-            table.add_row(k, "true" if show_dict[k] else "false")
-            for k in show_dict.keys()
+        table_headers = ["Supported Models", "Pretrained"]
+        table_items = [
+            (k, "true" if show_dict[k] else "false") for k in show_dict.keys()
         ]
-
-        print(table)
+        table = tabulate(
+            table_items, headers=table_headers, tablefmt="fancy_grid", **kwargs
+        )
+        return table
