@@ -8,6 +8,7 @@ import oneflow.nn as nn
 
 from .utils import load_state_dict_from_url
 from .registry import ModelCreator
+from .helpers import make_divisible
 
 
 model_urls = {
@@ -18,27 +19,6 @@ model_urls = {
 }
 
 
-def _make_divisible(channel_size, divisor=None, min_value=None):
-    """
-    This function is taken from the original tf repo.
-    It ensures that all layers have a channel number that is divisible by 8
-    It can be seen here:
-    https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet/mobilenet.py
-    """
-    if not divisor:
-        return channel_size
-
-    if min_value is None:
-        min_value = divisor
-    new_channel_size = max(
-        min_value, int(channel_size + divisor / 2) // divisor * divisor
-    )
-    # Make sure that round down does not go down by more than 10%.
-    if new_channel_size < 0.9 * channel_size:
-        new_channel_size += divisor
-    return new_channel_size
-
-
 def _add_conv(
     out,
     in_channels,
@@ -159,7 +139,7 @@ class ReXNetV1_lite(nn.Module):
         features = []
         inplanes = input_ch / multiplier if multiplier < 1.0 else input_ch
         first_channel = 32 / multiplier if multiplier < 1.0 or fix_head_stem else 32
-        first_channel = _make_divisible(
+        first_channel = make_divisible(
             int(round(first_channel * multiplier)), divisible_value
         )
 
@@ -178,7 +158,7 @@ class ReXNetV1_lite(nn.Module):
         )
 
         for i in range(self.num_convblocks):
-            inplanes_divisible = _make_divisible(
+            inplanes_divisible = make_divisible(
                 int(round(inplanes * multiplier)), divisible_value
             )
             if i == 0:
@@ -187,7 +167,7 @@ class ReXNetV1_lite(nn.Module):
             else:
                 in_channels_group.append(inplanes_divisible)
                 inplanes += final_ch / (self.num_convblocks - 1 * 1.0)
-                inplanes_divisible = _make_divisible(
+                inplanes_divisible = make_divisible(
                     int(round(inplanes * multiplier)), divisible_value
                 )
                 channels_group.append(inplanes_divisible)
@@ -248,7 +228,7 @@ def rexnet_lite_1_0(pretrained=False, progress=True, **kwargs):
 
     Args:
         pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
-        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+        progress (bool): If True, displays a progress bar of the download to stderr. Default: ``True``
 
     For example:
 
@@ -274,7 +254,7 @@ def rexnet_lite_1_3(pretrained=False, progress=True, **kwargs):
 
     Args:
         pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
-        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+        progress (bool): If True, displays a progress bar of the download to stderr. Default: ``True``
 
     For example:
 
@@ -300,7 +280,7 @@ def rexnet_lite_1_5(pretrained=False, progress=True, **kwargs):
 
     Args:
         pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
-        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+        progress (bool): If True, displays a progress bar of the download to stderr. Default: ``True``
 
     For example:
 
@@ -326,7 +306,7 @@ def rexnet_lite_2_0(pretrained=False, progress=True, **kwargs):
 
     Args:
         pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
-        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
+        progress (bool): If True, displays a progress bar of the download to stderr. Default: ``True``
 
     For example:
 
