@@ -1,17 +1,4 @@
 """
-Copyright 2020 The OneFlow Authors. All rights reserved.
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
 """
 from .transforms import (
     Compose,
@@ -37,8 +24,11 @@ from .transforms import (
     FiveCrop,
     TenCrop,
     InterpolationMode,
+    ToNumpy,
+    ColorJitter,
 )
 
+
 __all__ = [
     "Compose",
     "ToTensor",
@@ -63,4 +53,6 @@ __all__ = [
     "FiveCrop",
     "TenCrop",
     "InterpolationMode",
+    "ToNumpy",
+    "ColorJitter",
 ]
